/**
 * Sample React Native App
 * https://github.com/facebook/react-native
 *
 * @format
 * @flow strict-local
 */

 import React from 'react';
 import {
   SafeAreaView,
   ScrollView,
   StatusBar,
   StyleSheet,
   Text,
   useColorScheme,
   View,
 } from 'react-native';
 
 import {
   Colors,
   DebugInstructions,
   Header,
   LearnMoreLinks,
   ReloadInstructions,
 } from 'react-native/Libraries/NewAppScreen';
 
 import { Stack, Router, Scene, ActionConst } from 'react-native-router-flux';
 import { widthPercentageToDP as wp, heightPercentageToDP as hp } from 'react-native-responsive-screen';
 
 
 import SplashScreen from './src/screen/splash_screen/splashscreen';
 import HomeScreen from './src/screen/home_screen/homescreen';
 import BusListScreen from './src/screen/bus_list_screen/buslistscreen';
 import MapScreen from './src/screen/map_screen/mapscreen';
 import BusRoteScreen from './src/screen/bus_route_screen/busroutescreen';
 
 
 const App = () => {
   const isDarkMode = useColorScheme() === 'dark';
 
   const backgroundStyle = {
     backgroundColor: isDarkMode ? Colors.darker : Colors.lighter,
   };
 
   return (
     <Router>
       <Stack key="root" headerLayoutPreset="center">
         <Scene
           key="splash"
           type="replace"
           component={SplashScreen}
           initial
           hideNavBar={true}
         />
 
         <Scene
           key="authenticated"
           type="replace"
           renderTitle={() => (
             <View style={styles.navBarStyles}>
               <View style={styles.app_logs_holder}>
                 {/* <Image source={{ uri: 'tabbar_icon' }} style={styles.app_logs} /> */}
               </View>
             </View>
           )}
           //hideNavBar={true}
           panHandlers={null}
         >
           <Scene
             key="dashbord"
             title="Select Route And Bus off"
             component={HomeScreen}
             renderTitle={() => (
               <View style={styles.navBarStyles}>
                 <View style={styles.app_logs_holder}>
                   {/* <Image source={{ uri: 'tabbar_icon' }} style={styles.app_logs} /> */}
                   <Text style={{ color: '#000' }}>Select Route And Bus off</Text>
                 </View>
               </View>
             )}
             hideNavBar={true}
             initial
           />
           <Scene
             key="busRoute"
             title="Bus Details"
             component={BusRoteScreen}
             // renderTitle={() => (
             //   <View style={styles.navBarStyles}>
             //     <View style={styles.app_logs_holder}>
             //       {/* <Image source={{ uri: 'tabbar_icon' }} style={styles.app_logs} /> */}
             //     </View>
             //   </View>
             // )}
             hideNavBar={true}
           />
           <Scene
             key="busList"
             title="Bus Details"
             component={BusListScreen}
             // renderTitle={() => (
             //   <View style={styles.navBarStyles}>
             //     <View style={styles.app_logs_holder}>
             //       {/* <Image source={{ uri: 'tabbar_icon' }} style={styles.app_logs} /> */}
             //     </View>
             //   </View>
             // )}
             hideNavBar={true}
           />
           <Scene
             key="mapScreen"
             title="View On Map"
             component={MapScreen}
             // renderTitle={() => (
             //   <View style={styles.navBarStyles}>
             //     <View style={styles.app_logs_holder}>
             //       {/* <Image source={{ uri: 'tabbar_icon' }} style={styles.app_logs} /> */}
             //     </View>
             //   </View>
             // )}
             hideNavBar={true}
           />
         </Scene>
 
       </Stack>
     </Router>
   );
 };
 
 const styles = StyleSheet.create({
   sectionContainer: {
     marginTop: 32,
     paddingHorizontal: 24,
   },
   sectionTitle: {
     fontSize: 24,
     fontWeight: '600',
   },
   sectionDescription: {
     marginTop: 8,
     fontSize: 18,
     fontWeight: '400',
   },
   highlight: {
     fontWeight: '700',
   },
   navBarStyles: {
     width: "100%", //wp('100%')
     height: hp('7.5%'),
     alignItems: 'center',
     justifyContent: 'center',
   },
   app_logs_holder: {
     width: wp('10%'),
     height: hp('5%'),
     alignContent: 'center',
     alignItems: 'center',
   },
 });
 
 export default App;
 